from setuptools import setup, find_packages

setup(
    name='stopwordz',
    version='0.2',
    packages=find_packages(),
    description='A simple stopword cleaner',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Subashanan Nair',
    author_email='subaashnair12@gmail.com',
    url='https://github.com/subaashnair/stopwordz',
    install_requires=[
        # Any dependencies, for example: 'numpy'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)



import unittest
from stopwordz import clean_text

class TestCleanText(unittest.TestCase):
    def test_basic_cleaning(self):
        self.assertEqual(clean_text("Hello, world!"), "hello world")

    def test_with_punctuation(self):
        self.assertEqual(clean_text("Testing, testing, 1 2 3!"), "testing testing 1 2 3")

    def test_with_stopwords(self):
        self.assertEqual(clean_text("This is a test."), "test")

    def test_with_numbers(self):
        self.assertEqual(clean_text("123 testing, testing, 1 2 3!"), "123 testing testing 1 2 3")

if __name__ == '__main__':
    unittest.main()
